@@ -21,6 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#undef WNCK_DISABLE_DEPRECATED
+
 #include <config.h>
 
 #include <glib/gi18n-lib.h>
@@ -413,6 +415,9 @@ wnck_pid_read_resource_usage_fill_cache (struct xresclient_state *state)
   match_xid = (state->clients[state->next].resource_base &
                ~state->clients[state->next].resource_mask);
 
+  pid = 0;
+  xid = 0;
+
   for (i = 0; i < ScreenCount (state->xdisplay); i++)
     {
       Window root;
@@ -422,8 +427,6 @@ wnck_pid_read_resource_usage_fill_cache (struct xresclient_state *state)
       if (root == None)
         continue;
 
-      pid = 0;
-      xid = 0;
       wnck_find_pid_for_resource_r (state->xdisplay, root, match_xid,
                                     state->clients[state->next].resource_mask,
                                     &xid, &pid);
@@ -670,7 +673,7 @@ _wnck_get_client_type (void)
 }
 
 /**
- * _make_gtk_label_bold.
+ * _make_gtk_label_bold:
  *
  * Switches the font of label to a bold equivalent.
  * @label: The label.
