@@ -21,6 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#undef WNCK_DISABLE_DEPRECATED
+
 #include <config.h>
 
 #include <string.h>
@@ -208,13 +210,13 @@ item_activated_callback (GtkWidget *menu_item,
       if (!viewport_mode)
         wnck_window_pin (window);
       else
-        wnck_window_stick(window);
+        wnck_window_stick (window);
       break;
     case UNPIN:
       if (!viewport_mode)
         wnck_window_unpin (window);
       else
-        wnck_window_unstick(window);
+        wnck_window_unstick (window);
       break;
     case LEFT:
       if (!viewport_mode)
@@ -230,6 +232,7 @@ item_activated_callback (GtkWidget *menu_item,
 
           width = wnck_screen_get_width (screen);
           wnck_window_get_geometry (window, &xw, &yw, &ww, &hw);
+          wnck_window_unstick (window);
           wnck_window_set_geometry (window, 0,
                                     WNCK_WINDOW_CHANGE_X | WNCK_WINDOW_CHANGE_Y,
                                     xw - width, yw,
@@ -250,6 +253,7 @@ item_activated_callback (GtkWidget *menu_item,
 
           width = wnck_screen_get_width (screen);
           wnck_window_get_geometry (window, &xw, &yw, &ww, &hw);
+          wnck_window_unstick (window);
           wnck_window_set_geometry (window, 0,
                                     WNCK_WINDOW_CHANGE_X | WNCK_WINDOW_CHANGE_Y,
                                     xw + width, yw,
@@ -270,6 +274,7 @@ item_activated_callback (GtkWidget *menu_item,
 
           height = wnck_screen_get_height (screen);
           wnck_window_get_geometry (window, &xw, &yw, &ww, &hw);
+          wnck_window_unstick (window);
           wnck_window_set_geometry (window, 0,
                                     WNCK_WINDOW_CHANGE_X | WNCK_WINDOW_CHANGE_Y,
                                     xw, yw - height,
@@ -290,6 +295,7 @@ item_activated_callback (GtkWidget *menu_item,
 
           height = wnck_screen_get_height (screen);
           wnck_window_get_geometry (window, &xw, &yw, &ww, &hw);
+          wnck_window_unstick (window);
           wnck_window_set_geometry (window, 0,
                                     WNCK_WINDOW_CHANGE_X | WNCK_WINDOW_CHANGE_Y,
                                     xw, yw + height,
@@ -333,13 +339,11 @@ item_activated_callback (GtkWidget *menu_item,
           viewport_x = wnck_workspace_get_viewport_x (workspace);
           viewport_y = wnck_workspace_get_viewport_y (workspace);
 
-          xw += viewport_x;
-          yw += viewport_y;
-
+          wnck_window_unstick (window);
           wnck_window_set_geometry (window, 0,
                                     WNCK_WINDOW_CHANGE_X | WNCK_WINDOW_CHANGE_Y,
-                                    xw + new_viewport_x,
-                                    yw + new_viewport_y,
+                                    xw + new_viewport_x - viewport_x,
+                                    yw + new_viewport_y - viewport_y,
                                     ww, hw);
         }
       break;
