@@ -52,10 +52,10 @@
 /* VOID:FLAGS,FLAGS (wnck-marshal.list:25) */
 void
 _wnck_marshal_VOID__FLAGS_FLAGS (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLAGS_FLAGS) (gpointer     data1,
